<?php
/**
 * The template for adding color options in Customizer
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */

$wp_customize->add_panel( 'parallax_frame_color_options', array(
    'capability'     => 'edit_theme_options',
    'description'    => esc_html__( 'Color Options', 'parallax-frame-pro' ),
    'priority'       => 300,
    'title'    		 => esc_html__( 'Color Options', 'parallax-frame-pro' ),
) );


$wp_customize->add_setting( 'parallax_frame_theme_options[color_scheme]', array(
	'capability' 		=> 'edit_theme_options',
	'default'    		=> $defaults['color_scheme'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$schemes = parallax_frame_color_schemes();

$choices = array();

foreach ( $schemes as $scheme ) {
	$choices[ $scheme['value'] ] = $scheme['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[color_scheme]', array(
	'choices'  => $choices,
	'label'    => esc_html__( 'Color Scheme', 'parallax-frame-pro' ),
	'priority' => 5,
	'section'  => 'parallax_frame_basic_color',
	'settings' => 'parallax_frame_theme_options[color_scheme]',
	'type'     => 'radio',
) );

$color_headings = apply_filters( 'parallax_frame_color_options', 'color_headings' );

foreach ( $color_headings as $key_section => $title_section ) {
	$color_options	= apply_filters( 'parallax_frame_color_options', $key_section );

	$wp_customize->add_section( 'parallax_frame_' . $key_section, array(
		'panel' => 'parallax_frame_color_options',
		'title' => $title_section,
	) );

	$i = 10;
	foreach ( $color_options as $key => $label ) {
		$wp_customize->add_setting( 'parallax_frame_theme_options[' . $key . ']', array(
			'capability'        => 'edit_theme_options',
			'default'           => $defaults[ $key ],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'parallax_frame_theme_options[' . $key . ']', array(
			'label'    => $label,
			'priority' => $i,
			'section'  => 'parallax_frame_' . $key_section,
			'settings' => 'parallax_frame_theme_options[' . $key . ']',
		) ) );
		$i += 10;
	}
}

$wp_customize->add_setting( 'parallax_frame_theme_options[footer_sidebar_area_background_image]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['footer_sidebar_area_background_image'],
	'sanitize_callback' => 'parallax_frame_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'parallax_frame_theme_options[footer_sidebar_area_background_image]', array(
	'label'    => esc_html__( 'Sidebar Area Background Image', 'parallax-frame-pro' ),
	'priority' => 45,
	'section'  => 'parallax_frame_footer_color',
	'settings' => 'parallax_frame_theme_options[footer_sidebar_area_background_image]',
) ) );