<?php
/**
 * The template for displaying custom menus
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */



if ( ! function_exists( 'parallax_frame_primary_menu' ) ) :
/**
 * Shows the Primary Menu
 *
 * default load in sidebar-header-right.php
 */
function parallax_frame_primary_menu() {
    $options  = parallax_frame_get_theme_options();

    if ( !has_nav_menu( 'secondary' ) && $options['primary_menu_disable'] ) {
        //Bail if both secondary menu and primary menu are disabled
        return;
    }

    ?>
	<nav class="nav-primary" role="navigation">
    <?php
        $left_menu = false;
        $classes   = 'mobile-menu-anchor primary-menu';

        // Header Left Mobile Menu Anchor
        if ( has_nav_menu( 'secondary' ) ) {
            $classes   = "mobile-menu-anchor secondary-menu";

            if ( !$options['primary_menu_disable'] ) {
                $left_menu = true;
            }
        }

        if ( $left_menu ) {
            ?>
            <div id="mobile-header-left-menu" class="mobile-menu-anchor primary-menu">
                <a href="#mobile-header-left-nav" id="header-left-menu" class="genericon genericon-menu">
                    <span class="mobile-menu-text"><?php esc_html_e( 'Menu', 'parallax-frame-pro' );?></span>
                </a>
            </div><!-- #mobile-header-menu -->

            <?php
        }

        if ( !$options['primary_menu_disable'] ) {
            echo '<h1 class="screen-reader-text">' . esc_html__( 'Primary Menu', 'parallax-frame-pro' ) . '</h1>';

            wp_nav_menu(
                array(
                    'theme_location' => 'primary',
                    'menu_class'     => 'menu parallax-frame-nav-menu',
                    'container'      => false
                )
            );

            if ( !$options['disable_primary_search'] ) {
                ?>
                <div class="primary-search-icon">
                    <div id="search-toggle" class="genericon">
                        <a class="screen-reader-text" href="#search-container"><?php esc_html_e( 'Search', 'parallax-frame-pro' ); ?></a>
                    </div>

                    <div id="search-container" class="displaynone">
                        <?php get_search_form(); ?>
                    </div>
                </div><!-- .primary-search-icon -->

                <?php
            }
        }

        // Header Right Mobile Menu Anchor
        ?>
        <div id="mobile-header-right-menu" class="<?php echo $classes; ?>">
            <a href="#mobile-header-right-nav" id="header-right-menu" class="genericon genericon-menu">
                <span class="mobile-menu-text"><?php esc_html_e( 'Menu', 'parallax-frame-pro' );?></span>
            </a>
        </div><!-- #mobile-header-menu -->
    </nav><!-- .nav-primary -->
    <?php
}
endif; //parallax_frame_primary_menu


if ( ! function_exists( 'parallax_frame_footer_menu' ) ) :
/**
 * Shows the Footer Menu
 *
 * default load in sidebar-header-right.php
 */
function parallax_frame_footer_menu() {
	if ( has_nav_menu( 'footer' ) ) {
    ?>
	<nav class="nav-footer" role="navigation">
        <div class="wrapper">
            <?php
                $args = array(
                    'theme_location' => 'footer',
                    'menu_class'     => 'menu parallax-frame-nav-menu',
                    'depth'          =>  1
                );
                wp_nav_menu( $args );
            ?>
    	</div><!-- .wrapper -->
    </nav><!-- .nav-footer -->
<?php
    }
}
endif; //parallax_frame_footer_menu
add_action( 'parallax_frame_footer', 'parallax_frame_footer_menu', 40 );


if ( ! function_exists( 'parallax_frame_mobile_menus' ) ) :
/**
 * This function loads Mobile Menus
 *
 * @get the data value from theme options
 * @uses parallax_frame_after action to add the code in the footer
 */
function parallax_frame_mobile_menus() {
    //Getting Ready to load options data
    $options  = parallax_frame_get_theme_options();

    if ( !has_nav_menu( 'secondary' ) && $options['primary_menu_disable'] ) {
        //Bail if both secondary menu and primary menu are disabled
        return;
    }

    $left_menu_enabled = false;
    $classes   = 'mobile-menu-anchor primary-menu';

    $left_menu = $right_menu = wp_nav_menu(
        array(
            'theme_location' => 'primary',
            'container'      => false,
            'items_wrap'     => '<ul id="header-left-nav" class="menu primary">%3$s</ul>',
            'echo'           => false
        )
    );

    // Header Left Mobile Menu Anchor
    if ( has_nav_menu( 'secondary' ) ) {
        $classes = "mobile-menu-anchor secondary-menu";

        $right_menu = wp_nav_menu(
            array(
                'theme_location' => 'secondary',
                'container'      => false,
                'items_wrap'     => '<ul id="header-left-nav" class="menu secondary">%3$s</ul>',
                'echo'           => false
            )
        );

        if ( !$options['primary_menu_disable'] ) {
            $left_menu_enabled = true;
        }
    }

    //Header Left Menu
    if ( $left_menu_enabled ) {
        echo '<nav id="mobile-header-left-nav" class="mobile-menu" role="navigation">' . $left_menu . '</nav><!-- #mobile-header-left-nav -->';
    }

    //Header Right Menu
    echo '<nav id="mobile-header-right-nav" class="mobile-menu" role="navigation">' . $right_menu . '</nav><!-- #mobile-header-right-nav -->';
}
endif; //parallax_frame_mobile_menus

add_action( 'parallax_frame_after', 'parallax_frame_mobile_menus', 20 );
