<?php
/**
 * The template for adding Custom Sidebars and Widgets
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */

/**
 * Register widgetized area
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_widgets_init() {
	//Primary Sidebar
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'parallax-frame-pro' ),
		'id'            => 'primary-sidebar',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the primary sidebar if you are using a two column site layout option.', 'parallax-frame-pro' ),
	) );

	$footer_sidebar_number = 4; //Number of footer sidebars

	for( $i=1; $i <= $footer_sidebar_number; $i++ ) {
		register_sidebar( array(
			'name'          => sprintf( esc_html__( 'Footer Area %d', 'parallax-frame-pro' ), $i ),
			'id'            => sprintf( 'footer-%d', $i ),
			'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
			'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
			'description'	=> sprintf( esc_html__( 'Footer %d widget area.', 'parallax-frame-pro' ), $i ),
		) );
	}

	//Sidebar Before Content
	register_sidebar( array(
		'name'          => esc_html__( 'Before Content', 'parallax-frame-pro' ),
		'id'            => 'before-content',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Before Content widget area. It typically appears on the before the Content.', 'parallax-frame-pro' ),
	) );

	//Sidebar After Content
	register_sidebar( array(
		'name'          => esc_html__( 'After Content', 'parallax-frame-pro' ),
		'id'            => 'after-content',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the After Content widget area. It typically appears after the Content.', 'parallax-frame-pro' ),
	) );

	//Sidebar Before Posts/Pages
	register_sidebar( array(
		'name'          => esc_html__( 'Before Posts/Pages', 'parallax-frame-pro' ),
		'id'            => 'before-posts-pages',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Before Posts/Page widget area. It typically appears on the before Post/Page Content of the site title or logo.', 'parallax-frame-pro' ),
	) );

	//Sidebar After Posts/Pages
	register_sidebar( array(
		'name'          => esc_html__( 'After Posts/Pages', 'parallax-frame-pro' ),
		'id'            => 'after-posts-pages',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the After Posts/Page widget area. It typically appears after Post/Page Content.', 'parallax-frame-pro' ),
	) );

	//Featured Widget Content
	register_sidebar( array(
		'name'          => esc_html__( 'Featured Widget Content', 'parallax-frame-pro' ),
		'id'            => 'featured-widget-content',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Featured Widget Content. Enable it by going to Appearance => Customize => Featured Widget Content Options => Enable Featured content Widget Content on', 'parallax-frame-pro' ),
	) );

	//Promotion Headline Left
	register_sidebar( array(
		'name'          => esc_html__( 'Promotion Headline Left', 'parallax-frame-pro' ),
		'id'            => 'promotion-headline-left',
		'before_widget' => '<section id="%1$s" class="promotion-headline-section left widget %2$s">',
		'after_widget'  => '</section><!-- .section .left -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Promotion Headline Left. Enable it by going to Appearance => Customize => Theme Options => Promotion Headline Options.', 'parallax-frame-pro' ),
	) );

	//Promotion Headline Right
	register_sidebar( array(
		'name'          => esc_html__( 'Promotion Headline Right', 'parallax-frame-pro' ),
		'id'            => 'promotion-headline-right',
		'before_widget' => '<section id="%1$s" class="promotion-headline-section right widget %2$s">',
		'after_widget'  => '</section><!-- .section .right -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Promotion Headline Right. Enable it by going to Appearance => Customize => Theme Options => Promotion Headline Options.', 'parallax-frame-pro' ),
	) );

	// Registering 404 Error Page Content
	register_sidebar( array(
		'name'					=> esc_html__( '404 Page Not Found Content', 'parallax-frame-pro' ),
		'id' 					=> 'sidebar-notfound',
		'description'			=> esc_html__( 'Replaces the default 404 Page Not Found Content', 'parallax-frame-pro' ),
		'before_widget' 		=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  		=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'			=> '<h2 class="widget-title">',
		'after_title'			=> '</h2>',
	) );

	if ( class_exists( 'woocommerce' ) ) {
		//Optional Primary Sidebar for Shop
		register_sidebar( array(
			'name' 				=> esc_html__( 'WooCommerce Primary Sidebar', 'parallax-frame-pro' ),
			'id' 				=> 'sidebar-optional-woocommmerce',
			'description'		=> esc_html__( 'This is Optional Primary Sidebar for WooCommerce', 'parallax-frame-pro' ),
			'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
			'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
			'before_title' 		=> '<h2 class="widget-title">',
			'after_title' 		=> '</h2>'
		) );
	}

	//Optional Sidebar for Hompeage instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Homepage Sidebar', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-homepage',
		'description'		=> esc_html__( 'This is Optional Sidebar for Homepage', 'parallax-frame-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar for Archive instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Archive Sidebar', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-archive',
		'description'		=> esc_html__( 'This is Optional Sidebar for Archive', 'parallax-frame-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar for Page instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Page Sidebar', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-page',
		'description'		=> esc_html__( 'This is Optional Sidebar for Page', 'parallax-frame-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar for Post instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Post Sidebar', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-post',
		'description'		=> esc_html__( 'This is Optional Sidebar for Post', 'parallax-frame-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar one for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar One', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-one',
		'description'		=> esc_html__( 'This is Optional Sidebar One', 'parallax-frame-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar two for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar Two', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-two',
		'description'		=> esc_html__( 'This is Optional Sidebar Two', 'parallax-frame-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar Three for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar Three', 'parallax-frame-pro' ),
		'id' 				=> 'sidebar-optional-three',
		'description'		=> esc_html__( 'This is Optional Sidebar Three', 'parallax-frame-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );
}
add_action( 'widgets_init', 'parallax_frame_widgets_init' );

/**
 * Loads up Necessary JS Scripts for widgets
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_widgets_scripts( $hook) {
	if ( 'widgets.php' == $hook ) {
		wp_enqueue_style( 'parallax-frame-widgets-styles', get_template_directory_uri() . '/css/widgets.css' );
	}
}
add_action( 'admin_enqueue_scripts', 'parallax_frame_widgets_scripts' );

// Load About Widget
include get_template_directory() . '/inc/widgets/about.php';

// Load Advertisement Code Widget
include get_template_directory() . '/inc/widgets/advertisement-code.php';

// Load Advertisement Image Widget
include get_template_directory() . '/inc/widgets/advertisement-image.php';

// Load Featured Embed Widget
include get_template_directory() . '/inc/widgets/featured-embed.php';

// Load Featured Image Widget
include get_template_directory() . '/inc/widgets/featured-image.php';

// Load Featured Page Widget
include get_template_directory() . '/inc/widgets/featured-page.php';

// Load Featured Post Widget
include get_template_directory() . '/inc/widgets/featured-posts.php';

// Load Gallery Image Widget
include get_template_directory() . '/inc/widgets/gallery-image.php';

// Load Gallery Page Widget
include get_template_directory() . '/inc/widgets/gallery-page.php';

// Load Gallery Post Widget
include get_template_directory() . '/inc/widgets/gallery-posts.php';

// Load Instagram Widget
include get_template_directory() . '/inc/widgets/instagram.php';

// Load Newsletter Widget
include get_template_directory() . '/inc/widgets/newsletter.php';

// Load Social Icon Widget
include get_template_directory() . '/inc/widgets/social-icons.php';

// Load Newsletter Widget
include get_template_directory() . '/inc/widgets/tag-cloud.php';
